==> webkit2gtk_2.46.1.orig.tar.xz: webkitgtk-2.46.1/Source/JavaScriptCore/dfg/DFGDominators.h <==
/*
 * Copyright (C) 2011-2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#pragma once

#if ENABLE(DFG_JIT)

#include "DFGCFG.h"
#include "DFGGraph.h"
#include <wtf/Dominators.h>
#include <wtf/Noncopyable.h>
#include <wtf/TZoneMalloc.h>

namespace JSC { namespace DFG {

template <typename CFGKind>
class Dominators : public WTF::Dominators<CFGKind> {
    WTF_MAKE_NONCOPYABLE(Dominators);
    WTF_MAKE_TZONE_ALLOCATED(Dominators);
public:
    Dominators(Graph& graph)
        : WTF::Dominators<CFGKind>(selectCFG<CFGKind>(graph))
    {
    }
};

using SSADominators = Dominators<SSACFG>;
using CPSDominators = Dominators<CPSCFG>;

template <typename T, typename = typename std::enable_if<std::is_same<T, CPSCFG>::value>::type>
CPSDominators& ensureDominatorsForCFG(Graph& graph)
{
    return graph.ensureCPSDominators();
}

template <typename T, typename = typename std::enable_if<std::is_same<T, SSACFG>::value>::type>
SSADominators& ensureDominatorsForCFG(Graph& graph)
{
    return graph.ensureSSADominators();
}

} } // namespace JSC::DFG

#endif // ENABLE(DFG_JIT)

==> webkit2gtk_2.48.6.orig.tar.xz: webkitgtk-2.48.6/Source/JavaScriptCore/dfg/DFGDominators.h <==
/*
 * Copyright (C) 2011-2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#pragma once

#if ENABLE(DFG_JIT)

#include "DFGCFG.h"
#include "DFGGraph.h"
#include <wtf/Dominators.h>
#include <wtf/Noncopyable.h>
#include <wtf/TZoneMalloc.h>

namespace JSC { namespace DFG {

template <typename CFGKind>
class Dominators : public WTF::Dominators<CFGKind> {
    WTF_MAKE_NONCOPYABLE(Dominators);
    WTF_MAKE_TZONE_ALLOCATED_TEMPLATE(Dominators);
public:
    Dominators(Graph& graph)
        : WTF::Dominators<CFGKind>(selectCFG<CFGKind>(graph))
    {
    }
};

WTF_MAKE_TZONE_ALLOCATED_TEMPLATE_IMPL(template<typename CFGKind>, Dominators<CFGKind>);

using SSADominators = Dominators<SSACFG>;
using CPSDominators = Dominators<CPSCFG>;

template <typename T, typename = typename std::enable_if<std::is_same<T, CPSCFG>::value>::type>
CPSDominators& ensureDominatorsForCFG(Graph& graph)
{
    return graph.ensureCPSDominators();
}

template <typename T, typename = typename std::enable_if<std::is_same<T, SSACFG>::value>::type>
SSADominators& ensureDominatorsForCFG(Graph& graph)
{
    return graph.ensureSSADominators();
}

} } // namespace JSC::DFG

#endif // ENABLE(DFG_JIT)
